Method: OpenapiClient::UsersApi#replace_user

Defined in:
lib/openapi_client/api/users_api.rb

#replace_user(proj_id, env_id, user_id, user_create, opts = {}) ⇒ UserRead

Replace User

Parameters:

  • proj_id (String)

    Either the unique id of the project, or the URL-friendly key of the project (i.e: the \"slug\").

  • env_id (String)

    Either the unique id of the environment, or the URL-friendly key of the environment (i.e: the \"slug\").

  • user_id (String)

    Either the unique id of the user, or the URL-friendly key of the user (i.e: the \"slug\").

  • user_create (UserCreate)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



435
436
437
438
# File 'lib/openapi_client/api/users_api.rb', line 435

def replace_user(proj_id, env_id, user_id, user_create, opts = {})
  data, _status_code, _headers = replace_user_with_http_info(proj_id, env_id, user_id, user_create, opts)
  data
end