Method: PermitConfig#debug
- Defined in:
- lib/config.rb
#debug ⇒ Object
This class is used to configure the Permit SDK. It is used to set the base url of the PDP and the api key.
Example:
“‘ruby permit = Permit::Permit.new permit.config.base_url = ’pdp.permit.io’ permit.config “‘
12 13 14 |
# File 'lib/config.rb', line 12 def debug @debug end |